@@ -61,8 +61,6 @@ class ADCDevice:
     def read_fast(self):
         try:
             adc_value = self._adc.ADS1263_GetChannalValue(ADC_CHANNEL)
-            self._adc.ADS1263_WriteCmd(ADS1263_CMD['CMD_STOP1'])
-            time.sleep(20.0/1000.0)
             if adc_value >> 31 == 1:
                 value = REF * 2 - adc_value * REF / 0x80000000
             else:
@@ -134,7 +132,7 @@ class ScanCommand:
                         currentY = self._controller.extVcm.get_angle_y()
                         activeCavity = self._controller.get_active_cavity_index()
 
-                        detectorVoltage = self._controller.adc.read_fast()
+                        detectorVoltage = self._controller.adc.read()
                         self.results['active_cavity'].append(activeCavity)
                         self.results['x_set_point'].append(posX)
                         self.results['x'].append(currentX)
