@@ -140,7 +140,7 @@ class ECController(BaseController):
         except Exception as e:
             logging.error('Error in activating S2 {}'.format(e))
 
-    def move_to_wavelength(self, wl, timeout=2):
+    def move_to_wavelength(self, wl, timeout=0):
         self._driver.move_to_wavelength(wl, timeout)
 
 
@@ -253,8 +253,10 @@ class ECClient:
     def _is_wl_within_tolerance(self, wl_target, wl_now):
         return abs(wl_now - wl_target) < self.wlTolerance
 
-    def move_to_wavelength(self, wl, timeout=2):
+    def move_to_wavelength(self, wl, timeout=0):
         self._post('/stage/wavelength', params={'wavelength': wl})
+        if timeout == 0:
+            return
         start_time = time.time()
         while True:
             status = self._get('/stage/status')['response']['code']
